use serde::{Deserialize, Serialize};
use strum::{Display, EnumIter};

#[derive(Clone, Debug, PartialEq, Eq, Serialize, Deserialize, Display, EnumIter)]
#[serde(rename_all = "camelCase")]
pub enum DataType {
    Boolean,
    Int32,
    Int64,
    Float32,
    Float64,
    Date,
    DateTime,
    Time,
    Utf8,
    Other,
}

#[derive(Clone, Debug, PartialEq, Eq, Serialize, Deserialize, Display, EnumIter)]
#[serde(rename_all = "camelCase")]
pub enum LogicalType {
    Boolean,
    Categorical,
    Date,
    DateTime,
    Id,
    NaturalLanguage,
    Number,
    Other,
    Time,
    Null,
}

#[derive(Clone, Debug, PartialEq, Eq, Serialize, Deserialize)]
#[serde(rename_all = "camelCase")]
pub struct ColumnSchema {
    pub id: String,
    pub name: String,
    pub dtype: DataType,
    pub logical_type: LogicalType,
}

impl ColumnSchema {
    pub fn new<T: AsRef<str>>(name: T, dtype: DataType, logical_type: LogicalType) -> Self {
        Self {
            id: format!("{}", rand::random::<u32>()),
            name: name.as_ref().to_string(),
            dtype,
            logical_type,
        }
    }
}